# marco

[![pypi Version](https://img.shields.io/pypi/v/marco?label=version&logo=pypi&labelColor=22272E&color=blue)](https://pypi.org/project/marco/)

Statistics class automation module with python

## Install it

```bash
pip install marco
```
